@@ -91,11 +91,11 @@ class Store(Generic[State, Action, Event]):
         self._event_handlers_queue = queue.Queue[
             tuple[EventHandler[Event], Event] | None
         ]()
-        self_workers = [
+        workers = [
             _SideEffectRunnerThread(self._event_handlers_queue)
             for _ in range(self.store_options.threads)
         ]
-        for worker in self_workers:
+        for worker in workers:
             worker.start()
 
         self._is_running = Lock()
